==> python-maturin_1.7.4.orig.tar.gz: maturin-1.7.4/guide/src/index.md <==
# Maturin User Guide

Welcome to the maturin user guide! It contains examples and documentation to explain all of maturin's use cases in detail.

Please choose from the chapters on the left to jump to individual topics, or continue below to start with maturin's README.

## Sponsors

Development of maturin is made possible by the following sponsors:

<div class="sponsors">
  <div>
    <a rel="sponsored" target="_blank" href="https://astral.sh">
      <img src="./assets/sponsors/astral.png" alt="Astral" width="80" height="80" />
      <span>Astral</span>
    </a>
  </div>
  <div>
    <a rel="sponsored" target="_blank" href="http://bytewax.io">
      <img src="./assets/sponsors/bytewax.png" alt="Bytewax" width="80" height="80" />
      <span>Bytewax</span>
    </a>
  </div>
  <div>
    <a rel="sponsored" target="_blank" href="https://frontendmasters.com">
      <img src="./assets/sponsors/frontend-masters.png" alt="Frontend Masters" width="80" height="80" />
      <span>Frontend Masters</span>
    </a>
  </div>
  <div>
    <a rel="sponsored" target="_blank" href="https://pydantic.dev">
      <img src="./assets/sponsors/pydantic.png" alt="Pydantic" width="80" height="80" />
      <span>Pydantic</span>
    </a>
  </div>
  <div>
    <a rel="sponsored" target="_blank" href="https://www.rerun.io">
      <img src="./assets/sponsors/rerun.png" alt="Rerun" width="80" height="80" />
      <span>Rerun</span>
    </a>
  </div>
  <div>
    <a rel="sponsored" target="_blank" href="http://sentry.io">
      <img src="./assets/sponsors/sentry.png" alt="Sentry" width="80" height="80" />
      <span>Sentry</span>
    </a>
  </div>
  <div>
    <a rel="sponsored" target="_blank" href="https://tsycapital.com">
      <img src="./assets/sponsors/tsy-capital.png" alt="TSY Capital" width="80" height="80" />
      <span>TSY Capital</span>
    </a>
  </div>
</div>

And many more who kindly sponsor @messense on [GitHub Sponsors](https://github.com/sponsors/messense#sponsors).

{{#include ../../README.md}}

==> python-maturin_1.8.3.orig.tar.gz: maturin-1.8.3/guide/src/index.md <==
# Maturin User Guide

Welcome to the maturin user guide! It contains examples and documentation to explain all of maturin's use cases in detail.

Please choose from the chapters on the left to jump to individual topics, or continue below to start with maturin's README.

## Sponsors

Development of maturin is made possible by the following sponsors:

<div class="sponsors">
  <div>
    <a rel="sponsored" target="_blank" href="https://astral.sh">
      <img src="./assets/sponsors/astral.png" alt="Astral" width="80" height="80" />
      <span>Astral</span>
    </a>
  </div>
  <div>
    <a rel="sponsored" target="_blank" href="http://bytewax.io">
      <img src="./assets/sponsors/bytewax.png" alt="Bytewax" width="80" height="80" />
      <span>Bytewax</span>
    </a>
  </div>
  <div>
    <a rel="sponsored" target="_blank" href="https://frontendmasters.com">
      <img src="./assets/sponsors/frontend-masters.png" alt="Frontend Masters" width="80" height="80" />
      <span>Frontend Masters</span>
    </a>
  </div>
  <div>
    <a rel="sponsored" target="_blank" href="https://www.prefect.io">
      <img src="./assets/sponsors/prefect.png" alt="Prefect" width="80" height="80" />
      <span>Prefect</span>
    </a>
  </div>
  <div>
    <a rel="sponsored" target="_blank" href="https://pydantic.dev">
      <img src="./assets/sponsors/pydantic.png" alt="Pydantic" width="80" height="80" />
      <span>Pydantic</span>
    </a>
  </div>
  <div>
    <a rel="sponsored" target="_blank" href="https://www.rerun.io">
      <img src="./assets/sponsors/rerun.png" alt="Rerun" width="80" height="80" />
      <span>Rerun</span>
    </a>
  </div>
  <div>
    <a rel="sponsored" target="_blank" href="http://sentry.io">
      <img src="./assets/sponsors/sentry.png" alt="Sentry" width="80" height="80" />
      <span>Sentry</span>
    </a>
  </div>
  <div>
    <a rel="sponsored" target="_blank" href="https://tsycapital.com">
      <img src="./assets/sponsors/tsy-capital.png" alt="TSY Capital" width="80" height="80" />
      <span>TSY Capital</span>
    </a>
  </div>
</div>

And many more who kindly sponsor @messense on [GitHub Sponsors](https://github.com/sponsors/messense#sponsors).

{{#include ../../README.md}}
